import * as __aws_sdk_types from "@aws-sdk/types";
/**
 * GetSecretValueOutput shape
 */
export interface GetSecretValueOutput extends __aws_sdk_types.MetadataBearer {
    /**
     * <p>The ARN of the secret.</p>
     */
    ARN?: string;
    /**
     * <p>The friendly name of the secret.</p>
     */
    Name?: string;
    /**
     * <p>The unique identifier of this version of the secret.</p>
     */
    VersionId?: string;
    /**
     * <p>The decrypted part of the protected secret information that was originally provided as binary data in the form of a byte array. The response parameter represents the binary data as a <a href="https://tools.ietf.org/html/rfc4648#section-4">base64-encoded</a> string.</p> <p>This parameter is not used if the secret is created by the Secrets Manager console.</p> <p>If you store custom information in this field of the secret, then you must code your Lambda rotation function to parse and interpret whatever you store in the <code>SecretString</code> or <code>SecretBinary</code> fields.</p>
     */
    SecretBinary?: Uint8Array;
    /**
     * <p>The decrypted part of the protected secret information that was originally provided as a string.</p> <p>If you create this secret by using the Secrets Manager console then only the <code>SecretString</code> parameter contains data. Secrets Manager stores the information as a JSON structure of key/value pairs that the Lambda rotation function knows how to parse.</p> <p>If you store custom information in the secret by using the <a>CreateSecret</a>, <a>UpdateSecret</a>, or <a>PutSecretValue</a> API operations instead of the Secrets Manager console, or by using the <b>Other secret type</b> in the console, then you must code your Lambda rotation function to parse and interpret those values.</p>
     */
    SecretString?: string;
    /**
     * <p>A list of all of the staging labels currently attached to this version of the secret.</p>
     */
    VersionStages?: Array<string>;
    /**
     * <p>The date and time that this version of the secret was created.</p>
     */
    CreatedDate?: Date;
    /**
     * Metadata about the response received, including the HTTP status code, HTTP headers, and any request identifiers recognized by the SDK.
     */
    $metadata: __aws_sdk_types.ResponseMetadata;
}
